@@ -17,7 +17,7 @@
 package org.apache.streampark.common.util
 
 import java.text.{ParseException, SimpleDateFormat}
-import java.time.{Duration, LocalDateTime}
+import java.time.{Duration, LocalDateTime, ZoneId}
 import java.time.format.DateTimeFormatter
 import java.util._
 import java.util.concurrent.TimeUnit
@@ -154,7 +154,7 @@ object DateUtils {
    * @param milliseconds
    * @return
    */
-  def toDuration(milliseconds: Long): String = {
+  def toStringDuration(milliseconds: Long): String = {
     val duration = Duration.ofMillis(milliseconds)
     val days = duration.toDays
 
@@ -175,6 +175,13 @@ object DateUtils {
     builder.toString
   }
 
+  def toSecondDuration(time1: Date, time2: Date = new Date()): Long = {
+    val startDateTime = LocalDateTime.ofInstant(time1.toInstant, ZoneId.systemDefault());
+    val endDateTime = LocalDateTime.ofInstant(time2.toInstant, ZoneId.systemDefault());
+    val duration = Duration.between(startDateTime, endDateTime)
+    duration.toMillis / 1000
+  }
+
   def getTimeUnit(
       time: String,
       default: (Int, TimeUnit) = (5, TimeUnit.SECONDS)): (Int, TimeUnit) = {
