@@ -23,40 +23,40 @@
 # -----------------------------------------------------------------------------
 
 # Make sure prerequisite environment variables are set
-if [ -z "$JAVA_HOME" ] && [ -z "$JRE_HOME" ]; then
+if [[ -z "$JAVA_HOME" ]] && [[ -z "$JRE_HOME" ]]; then
   # shellcheck disable=SC2154
   if $darwin; then
     # Bugzilla 54390
-    if [ -x '/usr/libexec/java_home' ] ; then
+    if [[ -x '/usr/libexec/java_home' ]] ; then
       # shellcheck disable=SC2155
       export JAVA_HOME=$(/usr/libexec/java_home)
     # Bugzilla 37284 (reviewed).
-    elif [ -d "/System/Library/Frameworks/JavaVM.framework/Versions/CurrentJDK/Home" ]; then
+    elif [[ -d "/System/Library/Frameworks/JavaVM.framework/Versions/CurrentJDK/Home" ]]; then
       export JAVA_HOME="/System/Library/Frameworks/JavaVM.framework/Versions/CurrentJDK/Home"
     fi
   else
     JAVA_PATH=$(which java 2>/dev/null)
-    if [ "x$JAVA_PATH" != "x" ]; then
+    if [[ "x$JAVA_PATH" != "x" ]]; then
       JAVA_PATH=$(dirname "$JAVA_PATH" 2>/dev/null)
       JRE_HOME=$(dirname "$JAVA_PATH" 2>/dev/null)
     fi
-    if [ "x$JRE_HOME" = "x" ]; then
+    if [[ "x$JRE_HOME" = "x" ]]; then
       # XXX: Should we try other locations?
-      if [ -x /usr/bin/java ]; then
+      if [[ -x /usr/bin/java ]]; then
         JRE_HOME=/usr
       fi
     fi
   fi
-  if [ -z "$JAVA_HOME" ] && [ -z "$JRE_HOME" ]; then
+  if [[ -z "$JAVA_HOME" ]] && [[ -z "$JRE_HOME" ]]; then
     echo "Neither the JAVA_HOME nor the JRE_HOME environment variable is defined"
     echo "At least one of these environment variable is needed to run this program"
     exit 1
   fi
 fi
 
-if [ -z "$JRE_HOME" ]; then
+if [[ -z "$JRE_HOME" ]]; then
   # JAVA_HOME_MUST be set
-  if [ ! -x "$JAVA_HOME"/bin/java ]; then
+  if [[ ! -x "$JAVA_HOME"/bin/java ]]; then
     echo "The JAVA_HOME environment variable is not defined correctly"
     echo "JAVA_HOME=$JAVA_HOME"
     echo "This environment variable is needed to run this program"
@@ -65,7 +65,7 @@ if [ -z "$JRE_HOME" ]; then
   fi
   JRE_HOME="$JAVA_HOME"
 else
-  if [ ! -x "$JRE_HOME"/bin/java ]; then
+  if [[ ! -x "$JRE_HOME"/bin/java ]]; then
     echo "The JRE_HOME environment variable is not defined correctly"
     echo "JRE_HOME=$JRE_HOME"
     echo "This environment variable is needed to run this program"
@@ -74,6 +74,6 @@ else
 fi
 
 # Set standard commands for invoking Java, if not already set.
-if [ -z "$_RUNJAVA" ]; then
+if [[ -z "$_RUNJAVA" ]]; then
   _RUNJAVA="$JRE_HOME"/bin/java
 fi
