@@ -22,7 +22,8 @@ import org.apache.streampark.console.base.domain.RestResponse;
 import org.apache.streampark.console.base.exception.AbstractApiException;
 
 import org.apache.commons.lang3.StringUtils;
-import org.apache.shiro.authz.UnauthorizedException;
+import org.apache.shiro.authc.AuthenticationException;
+import org.apache.shiro.authz.UnauthenticatedException;
 
 import com.baomidou.mybatisplus.core.toolkit.StringPool;
 import lombok.extern.slf4j.Slf4j;
@@ -31,7 +32,6 @@ import org.springframework.core.annotation.Order;
 import org.springframework.http.HttpStatus;
 import org.springframework.validation.BindException;
 import org.springframework.validation.FieldError;
-import org.springframework.web.HttpRequestMethodNotSupportedException;
 import org.springframework.web.bind.annotation.ExceptionHandler;
 import org.springframework.web.bind.annotation.ResponseStatus;
 import org.springframework.web.bind.annotation.RestControllerAdvice;
@@ -48,19 +48,18 @@ import java.util.Set;
 @Order(value = Ordered.HIGHEST_PRECEDENCE)
 public class GlobalExceptionHandler {
 
-  @ExceptionHandler(value = Exception.class)
-  @ResponseStatus(HttpStatus.INTERNAL_SERVER_ERROR)
-  public RestResponse handleException(Exception e) {
-    log.info("Internal server error：", e);
-    return RestResponse.fail("internal server error: " + e.getMessage(), ResponseCode.CODE_FAIL);
+  @ExceptionHandler(value = UnauthenticatedException.class)
+  @ResponseStatus(HttpStatus.UNAUTHORIZED)
+  public RestResponse handelUnauthenticatedException(UnauthenticatedException e) {
+    log.info("Unauthenticated: {}", e.getMessage());
+    return RestResponse.fail("Unauthenticated.", ResponseCode.CODE_UNAUTHORIZED);
   }
 
-  @ExceptionHandler(value = HttpRequestMethodNotSupportedException.class)
-  @ResponseStatus(HttpStatus.INTERNAL_SERVER_ERROR)
-  public RestResponse handleException(HttpRequestMethodNotSupportedException e) {
-    log.info("not supported request method，exception：{}", e.getMessage());
-    return RestResponse.fail(
-        "not supported request method，exception：" + e.getMessage(), ResponseCode.CODE_FAIL);
+  @ExceptionHandler(value = AuthenticationException.class)
+  @ResponseStatus(HttpStatus.UNAUTHORIZED)
+  public RestResponse handelUnauthenticatedException(AuthenticationException e) {
+    log.info("Permission denied: {}", e.getMessage());
+    return RestResponse.fail("Permission denied.", ResponseCode.CODE_UNAUTHORIZED);
   }
 
   @ExceptionHandler(value = AbstractApiException.class)
@@ -70,6 +69,13 @@ public class GlobalExceptionHandler {
     return RestResponse.fail(e.getMessage(), e.getResponseCode());
   }
 
+  @ExceptionHandler(value = Exception.class)
+  @ResponseStatus(HttpStatus.INTERNAL_SERVER_ERROR)
+  @Order(value = Ordered.HIGHEST_PRECEDENCE)
+  public RestResponse handleException(Exception e) {
+    return RestResponse.fail("internal server error: " + e.getMessage(), ResponseCode.CODE_FAIL);
+  }
+
   /**
    * Unified processing of request parameter verification (entity object parameter transfer)
    *
@@ -108,10 +114,4 @@ public class GlobalExceptionHandler {
     message = new StringBuilder(message.substring(0, message.length() - 1));
     return RestResponse.fail(message.toString(), ResponseCode.CODE_FAIL);
   }
-
-  @ExceptionHandler(value = UnauthorizedException.class)
-  @ResponseStatus(HttpStatus.FORBIDDEN)
-  public void handleUnauthorizedException(Exception e) {
-    log.info("Permission denied，{}", e.getMessage());
-  }
 }
