@@ -24,6 +24,4 @@ import java.lang.annotation.Target;
 
 @Target(ElementType.METHOD)
 @Retention(RetentionPolicy.RUNTIME)
-public @interface ApiAccess {
-  boolean value() default true;
-}
+public @interface ApiAccess {}
