@@ -17,10 +17,12 @@
 
 package org.apache.streampark.console.core.bean;
 
-import lombok.Data;
+import lombok.Getter;
+import lombok.Setter;
 
 /** The robot alarm response of DingTalk And WeCom */
-@Data
+@Getter
+@Setter
 public class RobotResponse {
 
   private Integer errcode;
