@@ -19,7 +19,9 @@ package org.apache.streampark.console.core.controller;
 
 import org.apache.streampark.console.base.domain.RestRequest;
 import org.apache.streampark.console.base.domain.RestResponse;
+import org.apache.streampark.console.base.exception.ApiAlertException;
 import org.apache.streampark.console.base.exception.InternalException;
+import org.apache.streampark.console.core.annotation.PermissionScope;
 import org.apache.streampark.console.core.entity.Application;
 import org.apache.streampark.console.core.entity.FlinkSql;
 import org.apache.streampark.console.core.service.FlinkSqlService;
@@ -30,8 +32,6 @@ import org.apache.streampark.flink.core.FlinkSqlValidationResult;
 import org.apache.shiro.authz.annotation.RequiresPermissions;
 
 import com.baomidou.mybatisplus.core.metadata.IPage;
-import io.swagger.v3.oas.annotations.Operation;
-import io.swagger.v3.oas.annotations.tags.Tag;
 import lombok.extern.slf4j.Slf4j;
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.validation.annotation.Validated;
@@ -43,7 +43,6 @@ import javax.validation.constraints.NotNull;
 
 import java.util.List;
 
-@Tag(name = "FLINK_SQL_TAG")
 @Slf4j
 @Validated
 @RestController
@@ -56,7 +55,6 @@ public class FlinkSqlController {
 
   @Autowired private SqlCompleteService sqlComplete;
 
-  @Operation(summary = "Verify sql")
   @PostMapping("verify")
   public RestResponse verify(String sql, Long versionId, Long teamId) {
     sql = variableService.replaceVariable(teamId, sql);
@@ -83,24 +81,26 @@ public class FlinkSqlController {
     }
   }
 
-  @Operation(summary = "List the application sql")
   @PostMapping("list")
-  public RestResponse list(Long appId, RestRequest request) {
-    IPage<FlinkSql> page = flinkSqlService.page(appId, request);
+  @PermissionScope(app = "#flinkSql.appId", team = "#flinkSql.teamId")
+  public RestResponse list(FlinkSql flinkSql, RestRequest request) {
+    IPage<FlinkSql> page = flinkSqlService.page(flinkSql.getAppId(), request);
     return RestResponse.success(page);
   }
 
-  @Operation(summary = "Delete sql")
   @PostMapping("delete")
   @RequiresPermissions("sql:delete")
-  public RestResponse delete(Long id) {
-    Boolean deleted = flinkSqlService.removeById(id);
+  @PermissionScope(app = "#flinkSql.appId", team = "#teamId")
+  public RestResponse delete(FlinkSql flinkSql) {
+    Boolean deleted = flinkSqlService.removeById(flinkSql.getId());
     return RestResponse.success(deleted);
   }
 
-  @Operation(summary = "List sql by ids")
   @PostMapping("get")
-  public RestResponse get(String id) throws InternalException {
+  @PermissionScope(app = "#appId", team = "#teamId")
+  public RestResponse get(Long appId, Long teamId, String id) throws InternalException {
+    ApiAlertException.throwIfTrue(
+        appId == null || teamId == null, "Permission denied, appId and teamId cannot be null");
     String[] array = id.split(",");
     FlinkSql flinkSql1 = flinkSqlService.getById(array[0]);
     flinkSql1.base64Encode();
@@ -112,14 +112,13 @@ public class FlinkSqlController {
     return RestResponse.success(new FlinkSql[] {flinkSql1, flinkSql2});
   }
 
-  @Operation(summary = "List the applications sql histories")
   @PostMapping("history")
-  public RestResponse sqlhistory(Application application) {
-    List<FlinkSql> sqlList = flinkSqlService.history(application);
+  @PermissionScope(app = "#app.id", team = "#app.teamId")
+  public RestResponse sqlhistory(Application app) {
+    List<FlinkSql> sqlList = flinkSqlService.history(app);
     return RestResponse.success(sqlList);
   }
 
-  @Operation(summary = "Get the complete sql")
   @PostMapping("sqlComplete")
   public RestResponse getSqlComplete(@NotNull(message = "{required}") String sql) {
     return RestResponse.success().put("word", sqlComplete.getComplete(sql));
