@@ -20,7 +20,7 @@ package org.apache.streampark.console.core.controller;
 import org.apache.streampark.console.base.domain.RestRequest;
 import org.apache.streampark.console.base.domain.RestResponse;
 import org.apache.streampark.console.base.exception.InternalException;
-import org.apache.streampark.console.core.annotation.ApiAccess;
+import org.apache.streampark.console.core.annotation.PermissionScope;
 import org.apache.streampark.console.core.entity.Application;
 import org.apache.streampark.console.core.entity.SavePoint;
 import org.apache.streampark.console.core.service.ApplicationService;
@@ -29,11 +29,6 @@ import org.apache.streampark.console.core.service.SavePointService;
 import org.apache.shiro.authz.annotation.RequiresPermissions;
 
 import com.baomidou.mybatisplus.core.metadata.IPage;
-import io.swagger.v3.oas.annotations.Operation;
-import io.swagger.v3.oas.annotations.Parameter;
-import io.swagger.v3.oas.annotations.Parameters;
-import io.swagger.v3.oas.annotations.media.Schema;
-import io.swagger.v3.oas.annotations.tags.Tag;
 import lombok.extern.slf4j.Slf4j;
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.validation.annotation.Validated;
@@ -43,7 +38,6 @@ import org.springframework.web.bind.annotation.RestController;
 
 import javax.annotation.Nullable;
 
-@Tag(name = "SAVEPOINT_TAG")
 @Slf4j
 @Validated
 @RestController
@@ -54,50 +48,28 @@ public class SavePointController {
 
   @Autowired private SavePointService savePointService;
 
-  @Operation(summary = "Get application savepoint latest")
-  @PostMapping("latest")
-  public RestResponse latest(Long appId) {
-    SavePoint savePoint = savePointService.getLatest(appId);
-    return RestResponse.success(savePoint);
-  }
-
-  @Operation(summary = "List application savepoint histories")
   @PostMapping("history")
-  public RestResponse history(SavePoint savePoint, RestRequest request) {
-    IPage<SavePoint> page = savePointService.page(savePoint, request);
+  @PermissionScope(app = "#sp.appId", team = "#sp.teamId")
+  public RestResponse history(SavePoint sp, RestRequest request) {
+    IPage<SavePoint> page = savePointService.page(sp, request);
     return RestResponse.success(page);
   }
 
-  @Operation(summary = "Delete savepoint")
   @PostMapping("delete")
   @RequiresPermissions("savepoint:delete")
-  public RestResponse delete(Long id) throws InternalException {
-    SavePoint savePoint = savePointService.getById(id);
+  @PermissionScope(app = "#sp.appId", team = "#sp.teamId")
+  public RestResponse delete(SavePoint sp) throws InternalException {
+    SavePoint savePoint = savePointService.getById(sp.getId());
     Application application = applicationService.getById(savePoint.getAppId());
-    Boolean deleted = savePointService.delete(id, application);
+    Boolean deleted = savePointService.delete(sp.getId(), application);
     return RestResponse.success(deleted);
   }
 
-  @Operation(
-      summary = "Trigger savepoint",
-      description = "trigger savepoint for specified application")
-  @Parameters({
-    @Parameter(
-        name = "appId",
-        description = "app id",
-        required = true,
-        example = "100000",
-        schema = @Schema(implementation = Long.class)),
-    @Parameter(
-        name = "savepointPath",
-        description = "specified savepoint path",
-        schema = @Schema(implementation = String.class))
-  })
-  @ApiAccess
   @PostMapping("trigger")
   @RequiresPermissions("savepoint:trigger")
-  public RestResponse trigger(Long appId, @Nullable String savepointPath) {
-    savePointService.trigger(appId, savepointPath);
+  @PermissionScope(app = "#savePoint.appId", team = "#savePoint.teamId")
+  public RestResponse trigger(SavePoint savePoint, @Nullable String savepointPath) {
+    savePointService.trigger(savePoint.getAppId(), savepointPath);
     return RestResponse.success(true);
   }
 }
