@@ -83,9 +83,6 @@ public class Application implements Serializable {
   /** The name of the frontend and program displayed in yarn */
   private String jobName;
 
-  @TableField(updateStrategy = FieldStrategy.IGNORED)
-  private String appId;
-
   @TableField(updateStrategy = FieldStrategy.IGNORED)
   private String jobId;
 
@@ -96,7 +93,7 @@ public class Application implements Serializable {
   /** flink version */
   private Long versionId;
 
-  /** k8s cluster id */
+  /** 1. yarn application id(on yarn) 2. k8s application id (on k8s application) */
   private String clusterId;
 
   /** flink docker base image */
