@@ -17,7 +17,6 @@
 
 package org.apache.streampark.console.core.service.impl;
 
-import org.apache.streampark.console.base.domain.Constant;
 import org.apache.streampark.console.base.domain.RestRequest;
 import org.apache.streampark.console.base.mybatis.pager.MybatisPager;
 import org.apache.streampark.console.core.entity.ApplicationLog;
@@ -41,8 +40,8 @@ public class ApplicationLogServiceImpl extends ServiceImpl<ApplicationLogMapper,
 
   @Override
   public IPage<ApplicationLog> page(ApplicationLog applicationLog, RestRequest request) {
-    Page<ApplicationLog> page =
-        new MybatisPager<ApplicationLog>().getPage(request, "option_time", Constant.ORDER_DESC);
+    request.setSortField("option_time");
+    Page<ApplicationLog> page = MybatisPager.getPage(request);
     LambdaQueryWrapper<ApplicationLog> queryWrapper =
         new LambdaQueryWrapper<ApplicationLog>()
             .eq(ApplicationLog::getAppId, applicationLog.getAppId());
