@@ -517,6 +517,7 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
       }
     }
     this.baseMapper.page(page, appParam);
+
     List<Application> records = page.getRecords();
     long now = System.currentTimeMillis();
 
@@ -524,55 +525,43 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
     Map<Long, PipelineStatus> pipeStates = appBuildPipeService.listPipelineStatus(appIds);
 
     // add building pipeline status info and app control info
-    records =
-        records.stream()
-            .peek(
-                record -> {
-                  // 1) running Duration
-                  if (record.getTracking() == 1) {
-                    FlinkAppState state = record.getFlinkAppStateEnum();
-                    if (state == FlinkAppState.RUNNING
-                        || state == FlinkAppState.CANCELLING
-                        || state == FlinkAppState.MAPPING) {
-                      record.setDuration(now - record.getStartTime().getTime());
-                    }
-                  }
-                  // 2) k8s restURL
-                  if (record.isKubernetesModeJob()) {
-                    // set duration
-                    String restUrl =
-                        flinkK8sWatcher.getRemoteRestUrl(k8sWatcherWrapper.toTrackId(record));
-                    record.setFlinkRestUrl(restUrl);
-                  }
-                })
-            .peek(
-                record -> {
-                  // 3) buildStatus
-                  if (pipeStates.containsKey(record.getId())) {
-                    record.setBuildStatus(pipeStates.get(record.getId()).getCode());
-                  }
-                })
-            .peek(
-                record -> {
-                  // 4) appControl
-                  AppControl appControl =
-                      new AppControl()
-                          .setAllowBuild(
-                              record.getBuildStatus() == null
-                                  || !PipelineStatus.running
-                                      .getCode()
-                                      .equals(record.getBuildStatus()))
-                          .setAllowStart(
-                              !record.shouldBeTrack()
-                                  && PipelineStatus.success
-                                      .getCode()
-                                      .equals(record.getBuildStatus()))
-                          .setAllowStop(record.isRunning());
-                  record.setAppControl(appControl);
-                })
-            .collect(Collectors.toList());
+    records.forEach(
+        record -> {
+          // 1) running Duration
+          if (record.getTracking() == 1) {
+            FlinkAppState state = record.getFlinkAppStateEnum();
+            if (state == FlinkAppState.RUNNING
+                || state == FlinkAppState.CANCELLING
+                || state == FlinkAppState.MAPPING) {
+              record.setDuration(now - record.getStartTime().getTime());
+            }
+            // 2) k8s restURL
+            if (record.isKubernetesModeJob()) {
+              // set duration
+              String restUrl =
+                  flinkK8sWatcher.getRemoteRestUrl(k8sWatcherWrapper.toTrackId(record));
+              record.setFlinkRestUrl(restUrl);
+            }
+          }
+
+          // 3) buildStatus
+          if (pipeStates.containsKey(record.getId())) {
+            record.setBuildStatus(pipeStates.get(record.getId()).getCode());
+          }
+
+          // 4) appControl
+          AppControl appControl =
+              new AppControl()
+                  .setAllowBuild(
+                      record.getBuildStatus() == null
+                          || !PipelineStatus.running.getCode().equals(record.getBuildStatus()))
+                  .setAllowStart(
+                      !record.shouldBeTrack()
+                          && PipelineStatus.success.getCode().equals(record.getBuildStatus()))
+                  .setAllowStop(record.isRunning());
+          record.setAppControl(appControl);
+        });
 
-    page.setRecords(records);
     return page;
   }
 
@@ -614,8 +603,8 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
   }
 
   @Override
-  public List<String> getRecentK8sClusterId(Integer executionMode) {
-    return baseMapper.getRecentK8sClusterId(executionMode, DEFAULT_HISTORY_RECORD_LIMIT);
+  public List<String> getRecentK8sClusterId() {
+    return baseMapper.getRecentK8sClusterId(DEFAULT_HISTORY_RECORD_LIMIT);
   }
 
   @Override
@@ -845,56 +834,58 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
         !existsByJobName,
         "[StreamPark] Application names can't be repeated, copy application failed.");
 
-    Application oldApp = getById(appParam.getId());
+    Application persist = getById(appParam.getId());
     Application newApp = new Application();
     String jobName = appParam.getJobName();
 
     newApp.setJobName(jobName);
     newApp.setClusterId(
-        ExecutionMode.isSessionMode(oldApp.getExecutionModeEnum()) ? oldApp.getClusterId() : null);
-    newApp.setArgs(appParam.getArgs() != null ? appParam.getArgs() : oldApp.getArgs());
-    newApp.setVersionId(oldApp.getVersionId());
+        ExecutionMode.isSessionMode(persist.getExecutionModeEnum())
+            ? persist.getClusterId()
+            : null);
+    newApp.setArgs(appParam.getArgs() != null ? appParam.getArgs() : persist.getArgs());
+    newApp.setVersionId(persist.getVersionId());
 
-    newApp.setFlinkClusterId(oldApp.getFlinkClusterId());
-    newApp.setRestartSize(oldApp.getRestartSize());
-    newApp.setJobType(oldApp.getJobType());
-    newApp.setOptions(oldApp.getOptions());
-    newApp.setDynamicProperties(oldApp.getDynamicProperties());
-    newApp.setResolveOrder(oldApp.getResolveOrder());
-    newApp.setExecutionMode(oldApp.getExecutionMode());
-    newApp.setFlinkImage(oldApp.getFlinkImage());
-    newApp.setK8sNamespace(oldApp.getK8sNamespace());
-    newApp.setK8sRestExposedType(oldApp.getK8sRestExposedType());
-    newApp.setK8sPodTemplate(oldApp.getK8sPodTemplate());
-    newApp.setK8sJmPodTemplate(oldApp.getK8sJmPodTemplate());
-    newApp.setK8sTmPodTemplate(oldApp.getK8sTmPodTemplate());
-    newApp.setK8sHadoopIntegration(oldApp.getK8sHadoopIntegration());
-    newApp.setDescription(oldApp.getDescription());
-    newApp.setAlertId(oldApp.getAlertId());
-    newApp.setCpFailureAction(oldApp.getCpFailureAction());
-    newApp.setCpFailureRateInterval(oldApp.getCpFailureRateInterval());
-    newApp.setCpMaxFailureInterval(oldApp.getCpMaxFailureInterval());
-    newApp.setMainClass(oldApp.getMainClass());
-    newApp.setAppType(oldApp.getAppType());
-    newApp.setResourceFrom(oldApp.getResourceFrom());
-    newApp.setProjectId(oldApp.getProjectId());
-    newApp.setModule(oldApp.getModule());
+    newApp.setFlinkClusterId(persist.getFlinkClusterId());
+    newApp.setRestartSize(persist.getRestartSize());
+    newApp.setJobType(persist.getJobType());
+    newApp.setOptions(persist.getOptions());
+    newApp.setDynamicProperties(persist.getDynamicProperties());
+    newApp.setResolveOrder(persist.getResolveOrder());
+    newApp.setExecutionMode(persist.getExecutionMode());
+    newApp.setFlinkImage(persist.getFlinkImage());
+    newApp.setK8sNamespace(persist.getK8sNamespace());
+    newApp.setK8sRestExposedType(persist.getK8sRestExposedType());
+    newApp.setK8sPodTemplate(persist.getK8sPodTemplate());
+    newApp.setK8sJmPodTemplate(persist.getK8sJmPodTemplate());
+    newApp.setK8sTmPodTemplate(persist.getK8sTmPodTemplate());
+    newApp.setK8sHadoopIntegration(persist.getK8sHadoopIntegration());
+    newApp.setDescription(persist.getDescription());
+    newApp.setAlertId(persist.getAlertId());
+    newApp.setCpFailureAction(persist.getCpFailureAction());
+    newApp.setCpFailureRateInterval(persist.getCpFailureRateInterval());
+    newApp.setCpMaxFailureInterval(persist.getCpMaxFailureInterval());
+    newApp.setMainClass(persist.getMainClass());
+    newApp.setAppType(persist.getAppType());
+    newApp.setResourceFrom(persist.getResourceFrom());
+    newApp.setProjectId(persist.getProjectId());
+    newApp.setModule(persist.getModule());
     newApp.setUserId(serviceHelper.getUserId());
     newApp.setState(FlinkAppState.ADDED.getValue());
     newApp.setRelease(ReleaseState.NEED_RELEASE.get());
     newApp.setOptionState(OptionState.NONE.getValue());
-    newApp.setHotParams(oldApp.getHotParams());
+    newApp.setHotParams(persist.getHotParams());
 
     // createTime & modifyTime
     Date date = new Date();
     newApp.setCreateTime(date);
     newApp.setModifyTime(date);
 
-    newApp.setJar(oldApp.getJar());
-    newApp.setJarCheckSum(oldApp.getJarCheckSum());
-    newApp.setTags(oldApp.getTags());
-    newApp.setTeamId(oldApp.getTeamId());
-    newApp.setDependency(oldApp.getDependency());
+    newApp.setJar(persist.getJar());
+    newApp.setJarCheckSum(persist.getJarCheckSum());
+    newApp.setTags(persist.getTags());
+    newApp.setTeamId(persist.getTeamId());
+    newApp.setDependency(persist.getDependency());
 
     boolean saved = save(newApp);
     if (saved) {
@@ -919,7 +910,7 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
       return newApp.getId();
     } else {
       throw new ApiAlertException(
-          "create application from copy failed, copy source app: " + oldApp.getJobName());
+          "create application from copy failed, copy source app: " + persist.getJobName());
     }
   }
 
@@ -1001,7 +992,7 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
     application.setDynamicProperties(appParam.getDynamicProperties());
     application.setResolveOrder(appParam.getResolveOrder());
     application.setExecutionMode(appParam.getExecutionMode());
-    application.setClusterId(appParam.getClusterId());
+    application.setFlinkClusterId(appParam.getFlinkClusterId());
     application.setFlinkImage(appParam.getFlinkImage());
     application.updateHotParams(appParam);
     application.setK8sRestExposedType(appParam.getK8sRestExposedType());
@@ -1221,8 +1212,8 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
   }
 
   @Override
-  public String readConf(Application appParam) throws IOException {
-    File file = new File(appParam.getConfig());
+  public String readConf(String config) throws IOException {
+    File file = new File(config);
     String conf = FileUtils.readFileToString(file, StandardCharsets.UTF_8);
     return Base64.getEncoder().encodeToString(conf.getBytes());
   }
@@ -1296,6 +1287,7 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
   @Override
   public void cancel(Application appParam) throws Exception {
     FlinkAppHttpWatcher.setOptionState(appParam.getId(), OptionState.CANCELLING);
+
     Application application = getById(appParam.getId());
     application.setState(FlinkAppState.CANCELLING.getValue());
 
@@ -1304,11 +1296,15 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
     applicationLog.setAppId(application.getId());
     applicationLog.setJobManagerUrl(application.getJobManagerUrl());
     applicationLog.setOptionTime(new Date());
-    applicationLog.setYarnAppId(application.getClusterId());
+    if (ExecutionMode.isYarnMode(application.getExecutionMode())) {
+      applicationLog.setYarnAppId(application.getClusterId());
+    }
 
     if (appParam.getSavePointed()) {
-      FlinkAppHttpWatcher.addSavepoint(application.getId());
-      application.setOptionState(OptionState.SAVEPOINTING.getValue());
+      if (!application.isKubernetesModeJob()) {
+        FlinkAppHttpWatcher.addSavepoint(application.getId());
+        application.setOptionState(OptionState.SAVEPOINTING.getValue());
+      }
     } else {
       application.setOptionState(OptionState.CANCELLING.getValue());
     }
@@ -1359,7 +1355,7 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
             clusterId,
             application.getJobId(),
             appParam.getSavePointed(),
-            appParam.getDrain(),
+            appParam.getDrain() == null ? false : appParam.getDrain(),
             customSavepoint,
             namespace);
 
@@ -1513,7 +1509,9 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
     }
 
     starting(application);
-    application.setAllowNonRestored(appParam.getAllowNonRestored());
+
+    application.setAllowNonRestored(
+        appParam.getAllowNonRestored() == null ? false : appParam.getAllowNonRestored());
 
     String appConf;
     String flinkUserJar = null;
@@ -1620,17 +1618,10 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
     String k8sClusterId;
     FlinkK8sRestExposedType exposedType = null;
     if (application.getExecutionModeEnum() == ExecutionMode.KUBERNETES_NATIVE_SESSION) {
-      // For compatibility with historical versions
-      if (application.getFlinkClusterId() == null) {
-        k8sClusterId = application.getClusterId();
-        k8sNamespace = application.getK8sNamespace();
-        exposedType = application.getK8sRestExposedTypeEnum();
-      } else {
-        FlinkCluster cluster = flinkClusterService.getById(application.getFlinkClusterId());
-        k8sClusterId = cluster.getClusterId();
-        k8sNamespace = cluster.getK8sNamespace();
-        exposedType = cluster.getK8sRestExposedTypeEnum();
-      }
+      FlinkCluster cluster = flinkClusterService.getById(application.getFlinkClusterId());
+      k8sClusterId = cluster.getClusterId();
+      k8sNamespace = cluster.getK8sNamespace();
+      exposedType = cluster.getK8sRestExposedTypeEnum();
     } else if (application.getExecutionModeEnum() == ExecutionMode.KUBERNETES_NATIVE_APPLICATION) {
       k8sClusterId = application.getJobName();
       k8sNamespace = application.getK8sNamespace();
@@ -1644,7 +1635,7 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
         SubmitRequest.apply(
             flinkEnv.getFlinkVersion(),
             ExecutionMode.of(application.getExecutionMode()),
-            getProperties(application),
+            getProperties(application, flinkEnv),
             flinkEnv.getFlinkConf(),
             DevelopmentMode.of(application.getJobType()),
             application.getId(),
@@ -1708,7 +1699,7 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
           }
 
           if (ExecutionMode.isYarnMode(application.getExecutionMode())) {
-            application.setAppId(response.clusterId());
+            application.setClusterId(response.clusterId());
             applicationLog.setYarnAppId(response.clusterId());
           }
 
@@ -1758,7 +1749,7 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
         });
   }
 
-  private Map<String, Object> getProperties(Application application) {
+  private Map<String, Object> getProperties(Application application, FlinkEnv flinkEnv) {
     Map<String, Object> properties = application.getOptionMap();
     if (ExecutionMode.isRemoteMode(application.getExecutionModeEnum())) {
       FlinkCluster cluster = flinkClusterService.getById(application.getFlinkClusterId());
@@ -1796,11 +1787,10 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
     }
 
     if (ExecutionMode.isKubernetesApplicationMode(application.getExecutionMode())) {
-      try {
-        HadoopUtils.yarnClient();
-        properties.put(JobManagerOptions.ARCHIVE_DIR.key(), Workspace.ARCHIVES_FILE_PATH());
-      } catch (Exception e) {
-        // skip
+      String archiveDir =
+          flinkEnv.getFlinkConfig().getProperty(JobManagerOptions.ARCHIVE_DIR.key());
+      if (archiveDir != null) {
+        properties.put(JobManagerOptions.ARCHIVE_DIR.key(), archiveDir);
       }
     }
 
@@ -1866,7 +1856,7 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
   }
 
   private String getSavePointed(Application appParam) {
-    if (appParam.getSavePointed()) {
+    if (appParam.getSavePointed() != null && appParam.getSavePointed()) {
       if (StringUtils.isBlank(appParam.getSavePoint())) {
         SavePoint savePoint = savePointService.getLatest(appParam.getId());
         if (savePoint != null) {
@@ -1948,7 +1938,9 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
           .filter(report -> report.getName().equals(appName))
           .collect(Collectors.toList());
     } catch (Exception e) {
-      throw new RuntimeException("The yarn api is abnormal. Ensure that yarn is running properly.");
+      log.error("Failed to connect hadoop YARN, detail: {}", Utils.stringifyException(e));
+      throw new RuntimeException(
+          "Failed to connect hadoop YARN. Ensure that hadoop yarn is running.");
     }
   }
 
@@ -1960,26 +1952,21 @@ public class ApplicationServiceImpl extends ServiceImpl<ApplicationMapper, Appli
       case YARN_APPLICATION:
       case YARN_PER_JOB:
       case YARN_SESSION:
-        clusterId = application.getAppId();
+        clusterId = application.getClusterId();
         break;
       case KUBERNETES_NATIVE_APPLICATION:
         clusterId = application.getJobName();
         k8sNamespace = application.getK8sNamespace();
         break;
       case KUBERNETES_NATIVE_SESSION:
-        if (application.getFlinkClusterId() == null) {
-          clusterId = application.getClusterId();
-          k8sNamespace = application.getK8sNamespace();
-        } else {
-          cluster = flinkClusterService.getById(application.getFlinkClusterId());
-          ApiAlertException.throwIfNull(
-              cluster,
-              String.format(
-                  "The Kubernetes session clusterId=%s can't found, maybe the clusterId is wrong or the cluster has been deleted. Please contact the Admin.",
-                  application.getFlinkClusterId()));
-          clusterId = cluster.getClusterId();
-          k8sNamespace = cluster.getK8sNamespace();
-        }
+        cluster = flinkClusterService.getById(application.getFlinkClusterId());
+        ApiAlertException.throwIfNull(
+            cluster,
+            String.format(
+                "The Kubernetes session clusterId=%s can't found, maybe the clusterId is wrong or the cluster has been deleted. Please contact the Admin.",
+                application.getFlinkClusterId()));
+        clusterId = cluster.getClusterId();
+        k8sNamespace = cluster.getK8sNamespace();
         break;
       default:
         break;
