@@ -150,7 +150,7 @@ public class SavePointServiceImpl extends ServiceImpl<SavePointMapper, SavePoint
     }
 
     if (cpThreshold == 0) {
-      String flinkConfNumRetained = flinkEnv.convertFlinkYamlAsMap().get(numRetainedKey);
+      String flinkConfNumRetained = flinkEnv.getFlinkConfig().getProperty(numRetainedKey);
       int numRetainedDefaultValue = CheckpointingOptions.MAX_RETAINED_CHECKPOINTS.defaultValue();
       if (flinkConfNumRetained != null) {
         try {
@@ -273,7 +273,7 @@ public class SavePointServiceImpl extends ServiceImpl<SavePointMapper, SavePoint
       // flink
       FlinkEnv flinkEnv = flinkEnvService.getById(application.getVersionId());
       savepointPath =
-          flinkEnv.convertFlinkYamlAsMap().get(CheckpointingOptions.SAVEPOINT_DIRECTORY.key());
+          flinkEnv.getFlinkConfig().getProperty(CheckpointingOptions.SAVEPOINT_DIRECTORY.key());
     }
 
     return savepointPath;
@@ -289,14 +289,16 @@ public class SavePointServiceImpl extends ServiceImpl<SavePointMapper, SavePoint
     applicationLog.setAppId(application.getId());
     applicationLog.setJobManagerUrl(application.getJobManagerUrl());
     applicationLog.setOptionTime(new Date());
-    applicationLog.setYarnAppId(application.getClusterId());
-
-    FlinkAppHttpWatcher.addSavepoint(application.getId());
-
-    application.setOptionState(OptionState.SAVEPOINTING.getValue());
-    application.setOptionTime(new Date());
-    this.applicationService.updateById(application);
-    flinkAppHttpWatcher.initialize();
+    if (ExecutionMode.isYarnMode(application.getExecutionMode())) {
+      applicationLog.setYarnAppId(application.getClusterId());
+    }
+    if (!application.isKubernetesModeJob()) {
+      FlinkAppHttpWatcher.addSavepoint(application.getId());
+      application.setOptionState(OptionState.SAVEPOINTING.getValue());
+      application.setOptionTime(new Date());
+      this.applicationService.updateById(application);
+      flinkAppHttpWatcher.initialize();
+    }
 
     FlinkEnv flinkEnv = flinkEnvService.getById(application.getVersionId());
 
@@ -351,11 +353,13 @@ public class SavePointServiceImpl extends ServiceImpl<SavePointMapper, SavePoint
         .whenComplete(
             (t, e) -> {
               applicationLogService.save(applicationLog);
-              application.setOptionState(OptionState.NONE.getValue());
-              application.setOptionTime(new Date());
-              applicationService.update(application);
-              flinkAppHttpWatcher.cleanSavepoint(application);
-              flinkAppHttpWatcher.initialize();
+              if (!application.isKubernetesModeJob()) {
+                application.setOptionState(OptionState.NONE.getValue());
+                application.setOptionTime(new Date());
+                applicationService.update(application);
+                flinkAppHttpWatcher.cleanSavepoint(application);
+                flinkAppHttpWatcher.initialize();
+              }
             });
   }
 
@@ -393,7 +397,9 @@ public class SavePointServiceImpl extends ServiceImpl<SavePointMapper, SavePoint
 
   private String getClusterId(Application application, FlinkCluster cluster) {
     if (ExecutionMode.isKubernetesMode(application.getExecutionMode())) {
-      return application.getClusterId();
+      return ExecutionMode.isKubernetesSessionMode(application.getExecutionMode())
+          ? cluster.getClusterId()
+          : application.getClusterId();
     } else if (ExecutionMode.isYarnMode(application.getExecutionMode())) {
       if (ExecutionMode.YARN_SESSION.equals(application.getExecutionModeEnum())) {
         Utils.notNull(
@@ -403,7 +409,7 @@ public class SavePointServiceImpl extends ServiceImpl<SavePointMapper, SavePoint
                 application.getFlinkClusterId()));
         return cluster.getClusterId();
       } else {
-        return application.getAppId();
+        return application.getClusterId();
       }
     }
     return null;
