@@ -27,8 +27,8 @@ import org.apache.streampark.console.core.entity.Variable;
 import org.apache.streampark.console.core.enums.ReleaseState;
 import org.apache.streampark.console.core.mapper.VariableMapper;
 import org.apache.streampark.console.core.service.ApplicationService;
-import org.apache.streampark.console.core.service.CommonService;
 import org.apache.streampark.console.core.service.FlinkSqlService;
+import org.apache.streampark.console.core.service.ServiceHelper;
 import org.apache.streampark.console.core.service.VariableService;
 
 import org.apache.commons.collections.CollectionUtils;
@@ -46,6 +46,7 @@ import org.springframework.transaction.annotation.Propagation;
 import org.springframework.transaction.annotation.Transactional;
 
 import java.util.ArrayList;
+import java.util.Date;
 import java.util.List;
 import java.util.Map;
 import java.util.regex.Matcher;
@@ -69,7 +70,7 @@ public class VariableServiceImpl extends ServiceImpl<VariableMapper, Variable>
 
   @Autowired private FlinkSqlService flinkSqlService;
 
-  @Autowired private CommonService commonService;
+  @Autowired private ServiceHelper serviceHelper;
 
   @Override
   @Transactional(rollbackFor = Exception.class)
@@ -77,7 +78,11 @@ public class VariableServiceImpl extends ServiceImpl<VariableMapper, Variable>
     if (this.findByVariableCode(variable.getTeamId(), variable.getVariableCode()) != null) {
       throw new ApiAlertException("Sorry, the variable code already exists.");
     }
-    variable.setCreatorId(commonService.getUserId());
+    variable.setCreatorId(serviceHelper.getUserId());
+
+    Date date = new Date();
+    variable.setCreateTime(date);
+    variable.setModifyTime(date);
     this.save(variable);
   }
 
@@ -95,7 +100,7 @@ public class VariableServiceImpl extends ServiceImpl<VariableMapper, Variable>
     if (variable.getTeamId() == null) {
       return null;
     }
-    Page<Variable> page = new MybatisPager<Variable>().getDefaultPage(request);
+    Page<Variable> page = MybatisPager.getPage(request);
     return this.baseMapper.page(page, variable);
   }
 
@@ -130,6 +135,8 @@ public class VariableServiceImpl extends ServiceImpl<VariableMapper, Variable>
     if (!findVariable.getVariableCode().equals(variable.getVariableCode())) {
       throw new ApiAlertException("Sorry, the variable code cannot be updated.");
     }
+
+    variable.setModifyTime(new Date());
     this.baseMapper.updateById(variable);
     // endregion
 
