@@ -19,25 +19,30 @@ package org.apache.streampark.console.system.authentication;
 
 import org.apache.shiro.authc.AuthenticationToken;
 
-import lombok.Data;
+import lombok.Getter;
+import lombok.Setter;
 
 /** JSON Web Token */
-@Data
+@Getter
+@Setter
 public class JWTToken implements AuthenticationToken {
 
-  private static final long serialVersionUID = 1282057025599826155L;
+  private static final long serialVersionUID = 1L;
 
   private String token;
 
   private String expireAt;
 
+  private int signType;
+
   public JWTToken(String token) {
     this.token = token;
   }
 
-  public JWTToken(String token, String expireAt) {
+  public JWTToken(String token, String expireAt, int signType) {
     this.token = token;
     this.expireAt = expireAt;
+    this.signType = signType;
   }
 
   @Override
