@@ -20,6 +20,7 @@ package org.apache.streampark.console.system.service.impl;
 import org.apache.streampark.console.base.domain.Constant;
 import org.apache.streampark.console.base.domain.RestRequest;
 import org.apache.streampark.console.base.exception.ApiAlertException;
+import org.apache.streampark.console.base.mybatis.pager.MybatisPager;
 import org.apache.streampark.console.system.entity.Role;
 import org.apache.streampark.console.system.entity.RoleMenu;
 import org.apache.streampark.console.system.mapper.RoleMapper;
@@ -58,10 +59,8 @@ public class RoleServiceImpl extends ServiceImpl<RoleMapper, Role> implements Ro
   @Autowired private RoleMenuServie roleMenuService;
 
   @Override
-  public IPage<Role> findRoles(Role role, RestRequest request) {
-    Page<Role> page = new Page<>();
-    page.setCurrent(request.getPageNum());
-    page.setSize(request.getPageSize());
+  public IPage<Role> page(Role role, RestRequest request) {
+    Page<Role> page = MybatisPager.getPage(request);
     return this.baseMapper.findRole(page, role);
   }
 
@@ -72,7 +71,9 @@ public class RoleServiceImpl extends ServiceImpl<RoleMapper, Role> implements Ro
 
   @Override
   public void createRole(Role role) {
-    role.setCreateTime(new Date());
+    Date date = new Date();
+    role.setCreateTime(date);
+    role.setModifyTime(date);
     this.save(role);
 
     String[] menuIds = role.getMenuId().split(StringPool.COMMA);
