@@ -34,8 +34,6 @@ export default {
     cvs: 'CVS',
     prvkeyPath: '私钥路径',
     prvkeyPathPlaceholder: '私钥文件路径, 如: ~/.ssh/id_rsa',
-    gitCredential: '连接方式',
-    gitCredentialPlaceholder: 'Git连接方式, http/ssh',
     cvsPlaceholder: 'CVS类型: git/svn',
     repositoryURL: '仓库地址',
     repositoryURLPlaceholder: '请输入该项目的仓库地址',
@@ -61,7 +59,6 @@ export default {
     projectNameIsRequiredMessage: '项目名称必填',
     projectNameIsUniqueMessage: '项目名称已存在，请再次输入',
     projectTypeIsRequiredMessage: '项目类型必选',
-    gitCredentialIsRequiredMessage: 'Git连接方式为必填项',
     cvsIsRequiredMessage: '资源来源必选',
     repositoryURLIsRequiredMessage: '(项目)仓库地址必填',
     pomSpecifiesModuleMessage: '指定编译pom.xml的模块 如未指定，则在根路径pom.xml下找到',
