@@ -24,48 +24,48 @@ export default {
   form: {
     clusterName: '集群名称',
     address: '集群URL',
-    executionMode: '执行模式',
-    versionId: 'Flink版本',
+    executionMode: '运行模式',
+    versionId: 'Flink 版本',
     addType: '添加类型',
     addExisting: '已有集群',
     addNew: '全新集群',
-    yarnQueue: 'Yarn队列',
-    yarnSessionClusterId: 'Yarn Session模式集群ID',
-    k8sNamespace: 'K8S命名空间',
-    k8sClusterId: 'K8S集群ID',
-    k8sSessionCluster: 'k8s Session集群',
-    serviceAccount: 'K8S服务账号',
-    k8sConf: 'K8S环境Kube配置文件',
-    flinkImage: 'Flink基础docker镜像',
-    k8sRestExposedType: 'K8S服务对外类型',
+    yarnQueue: 'Yarn 队列',
+    yarnSessionClusterId: 'Yarn Session 模式集群ID',
+    k8sNamespace: 'K8S 命名空间',
+    k8sClusterId: 'K8S 集群ID',
+    k8sSessionCluster: 'k8s Session 集群',
+    serviceAccount: 'K8S 服务账号',
+    k8sConf: 'K8S 环境Kube配置文件',
+    flinkImage: 'Flink 基础docker镜像',
+    k8sRestExposedType: 'K8S 服务对外类型',
     resolveOrder: '类加载顺序',
     taskSlots: '任务槽数',
-    jmOptions: 'JM内存',
-    tmOptions: 'TM内存',
+    jmOptions: 'JM 内存',
+    tmOptions: 'TM 内存',
     dynamicProperties: '动态参数',
     clusterDescription: '集群描述',
   },
   placeholder: {
     addType: '请选择集群添加类型',
     clusterName: '请输入集群名称',
-    executionMode: '请选择执行模式',
-    versionId: '请选择Flink版本',
-    addressRemoteMode: '请输入Flink 集群JobManager URL访问地址',
+    executionMode: '请选择运行模式',
+    versionId: '请选择 Flink 版本',
+    addressRemoteMode: '请输入 Flink 集群 JobManager URL 访问地址',
     addressNoRemoteMode: '请输入集群地址，例如：http://host:port',
     yarnSessionClusterId: '请输入Yarn Session模式集群ID',
     k8sConf: '示例：~/.kube/config',
     flinkImage: '请输入Flink基础docker镜像的标签，如：flink:1.13.0-scala_2.11-java8',
     k8sRestExposedType: 'kubernetes.rest-service.exposed.type',
     resolveOrder: 'classloader.resolve-order',
-    taskSlots: '每个TaskManager的插槽数',
+    taskSlots: '每个 TaskManager 的插槽数',
     totalOptions: '总内存',
-    jmOptions: '请选择要设置的jm资源参数',
-    tmOptions: '请选择要设置的tm资源参数',
+    jmOptions: '请选择要设置的 JobManager 资源参数',
+    tmOptions: '请选择要设置的 TaskManager 资源参数',
     clusterDescription: '集群描述信息, 如: 生产flink 1.16集群',
   },
   required: {
     address: '必须填写集群地址',
-    executionMode: '执行模式必填',
+    executionMode: '运行模式必填',
     clusterId: 'Yarn Session Cluster 为必填项',
     versionId: 'Flink 版本必选',
     flinkImage: 'link基础docker镜像是必填的',
