@@ -33,7 +33,7 @@ import optionData from '../../flink/app/data/option';
 import {
   fetchFlinkBaseImages,
   fetchK8sNamespaces,
-  fetchSessionClusterIds,
+  fetchK8sSessionClusterId,
 } from '/@/api/flink/app/flinkHistory';
 import { handleFormValue } from '../../flink/app/utils';
 import { useMessage } from '/@/hooks/web/useMessage';
@@ -118,8 +118,8 @@ export const useClusterSetting = () => {
           placeholder: t('setting.flinkCluster.placeholder.executionMode'),
           options: [
             {
-              label: 'remote',
-              value: ExecModeEnum.REMOTE,
+              label: 'standalone',
+              value: ExecModeEnum.STANDALONE,
             },
             { label: 'yarn session', value: ExecModeEnum.YARN_SESSION },
             { label: 'kubernetes session', value: ExecModeEnum.KUBERNETES_SESSION },
@@ -147,7 +147,7 @@ export const useClusterSetting = () => {
         componentProps: {
           placeholder: t('setting.flinkCluster.placeholder.addressRemoteMode'),
         },
-        ifShow: ({ values }) => values.executionMode == ExecModeEnum.REMOTE,
+        ifShow: ({ values }) => values.executionMode == ExecModeEnum.STANDALONE,
         rules: [{ required: true, message: t('setting.flinkCluster.required.address') }],
       },
       {
@@ -333,7 +333,7 @@ export const useClusterSetting = () => {
     };
 
     switch (values.executionMode) {
-      case ExecModeEnum.REMOTE:
+      case ExecModeEnum.STANDALONE:
         Object.assign(params, {
           address: values.address,
         });
@@ -371,9 +371,7 @@ export const useClusterSetting = () => {
     fetchK8sNamespaces().then((res) => {
       historyRecord.k8sNamespace = res;
     });
-    fetchSessionClusterIds({
-      executionMode: ExecModeEnum.KUBERNETES_SESSION,
-    }).then((res) => {
+    fetchK8sSessionClusterId().then((res) => {
       historyRecord.k8sSessionClusterId = res;
     });
     fetchFlinkBaseImages().then((res) => {
