@@ -20,7 +20,6 @@ import { Switch } from 'ant-design-vue';
 import { useMessage } from '/@/hooks/web/useMessage';
 import { fetTokenStatusToggle } from '/@/api/system/token';
 import { getNoTokenUserList } from '/@/api/system/user';
-import dayjs from 'dayjs';
 import { useI18n } from '/@/hooks/web/useI18n';
 const { t } = useI18n();
 
@@ -51,11 +50,6 @@ export const columns: BasicColumn[] = [
     title: t('common.createTime'),
     dataIndex: 'createTime',
   },
-  {
-    title: t('system.token.table.expireTime'),
-    dataIndex: 'expireTime',
-    sorter: true,
-  },
   {
     title: t('system.token.table.status'),
     dataIndex: 'userStatus',
@@ -117,13 +111,4 @@ export const formSchema: FormSchema[] = [
     label: t('common.description'),
     component: 'InputTextArea',
   },
-  {
-    field: 'expireTime',
-    label: t('system.token.table.expireTime'),
-    component: 'DatePicker',
-    defaultValue: dayjs('9999-01-01'),
-    componentProps: {
-      disabled: true,
-    },
-  },
 ];
