@@ -41,7 +41,7 @@ object FlinkJobState extends Enumeration {
       SUSPENDED, RECONCILING = Value
 
   // ending flink states, the tracking monitor will stop tracking these states of flink job.
-  val endingStates = Seq(FAILED, CANCELED, FINISHED, POS_TERMINATED, TERMINATED, LOST)
+  private val endingStates = Seq(FAILED, CANCELED, FINISHED, POS_TERMINATED, TERMINATED, LOST)
 
   def of(value: String): FlinkJobState.Value = {
     this.values.find(_.toString == value).getOrElse(OTHER)
