@@ -21,13 +21,14 @@ import org.apache.streampark.common.conf.Workspace
 import org.apache.streampark.common.util.Logger
 import org.apache.streampark.flink.kubernetes.{ChangeEventBus, FlinkK8sWatchController, JobStatusWatcherConfig, KubernetesRetriever}
 import org.apache.streampark.flink.kubernetes.enums.{FlinkJobState, FlinkK8sExecuteMode}
-import org.apache.streampark.flink.kubernetes.enums.FlinkK8sExecuteMode.APPLICATION
+import org.apache.streampark.flink.kubernetes.enums.FlinkK8sExecuteMode.{APPLICATION, SESSION}
 import org.apache.streampark.flink.kubernetes.event.FlinkJobStatusChangeEvent
 import org.apache.streampark.flink.kubernetes.helper.KubernetesDeploymentHelper
 import org.apache.streampark.flink.kubernetes.model._
 
 import com.google.common.base.Charsets
 import com.google.common.io.Files
+import org.apache.flink.configuration.JobManagerOptions
 import org.apache.flink.core.fs.Path
 import org.apache.flink.runtime.history.FsJobArchivist
 import org.apache.hc.client5.http.fluent.Request
@@ -40,7 +41,7 @@ import javax.annotation.concurrent.ThreadSafe
 
 import java.io.File
 import java.nio.charset.StandardCharsets
-import java.util.concurrent.{Executors, ScheduledFuture, TimeUnit}
+import java.util.concurrent.{ScheduledFuture, TimeUnit}
 
 import scala.collection.JavaConversions._
 import scala.concurrent.{Await, ExecutionContext, ExecutionContextExecutorService, Future}
@@ -60,30 +61,32 @@ class FlinkJobStatusWatcher(conf: JobStatusWatcherConfig = JobStatusWatcherConfi
   extends Logger
   with FlinkWatcher {
 
-  private val trackTaskExecPool = Executors.newWorkStealingPool()
   implicit private val trackTaskExecutor: ExecutionContextExecutorService =
-    ExecutionContext.fromExecutorService(trackTaskExecPool)
+    ExecutionContext.fromExecutorService(watchExecutor)
 
-  private val timerExec = Executors.newSingleThreadScheduledExecutor()
   private var timerSchedule: ScheduledFuture[_] = _
 
   /** stop watcher process */
   override def doStart(): Unit = {
-    timerSchedule =
-      timerExec.scheduleAtFixedRate(() => doWatch(), 0, conf.requestIntervalSec, TimeUnit.SECONDS)
+    timerSchedule = watchExecutor.scheduleAtFixedRate(
+      () => doWatch(),
+      0,
+      conf.requestIntervalSec,
+      TimeUnit.SECONDS)
     logInfo("[flink-k8s] FlinkJobStatusWatcher started.")
   }
 
   /** stop watcher process */
   override def doStop(): Unit = {
     // interrupt all running threads
-    timerSchedule.cancel(true)
+    if (!timerSchedule.isCancelled) {
+      timerSchedule.cancel(true)
+    }
     logInfo("[flink-k8s] FlinkJobStatusWatcher stopped.")
   }
 
   /** closes resource, relinquishing any underlying resources. */
   override def doClose(): Unit = {
-    timerExec.shutdownNow()
     trackTaskExecutor.shutdownNow()
     logInfo("[flink-k8s] FlinkJobStatusWatcher closed.")
   }
@@ -114,27 +117,24 @@ class FlinkJobStatusWatcher(conf: JobStatusWatcherConfig = JobStatusWatcherConfi
       val sessionIds = trackIds.filter(_.executeMode == FlinkK8sExecuteMode.SESSION)
       val sessionCluster = sessionIds.groupBy(_.toClusterKey.toString).flatMap(_._2).toSet
       val sessionFuture = sessionCluster.map {
-        id =>
-          val future = Future(touchSessionAllJob(id))
+        trackId =>
+          val future = Future(touchSessionAllJob(trackId))
           future.onComplete(_.toOption match {
             case Some(map) =>
-              sessionIds.foreach(
-                id => {
-                  map.find(_._1.jobId == id.jobId) match {
-                    case Some(job) =>
-                      updateState(job._1.copy(appId = id.appId), job._2)
+              map.find(_._1.jobId == trackId.jobId) match {
+                case Some(job) =>
+                  updateState(job._1.copy(appId = trackId.appId), job._2)
+                case _ =>
+                  touchSessionJob(trackId) match {
+                    case Some(state) =>
+                      if (FlinkJobState.isEndState(state.jobState)) {
+                        // can't find that job in the k8s cluster.
+                        watchController.unWatching(trackId)
+                      }
+                      eventBus.postSync(FlinkJobStatusChangeEvent(trackId, state))
                     case _ =>
-                      // can't find that job in the k8s cluster.
-                      watchController.unWatching(id)
-                      val lostState = JobStatusCV(
-                        jobState = FlinkJobState.LOST,
-                        jobId = id.jobId,
-                        pollEmitTime = System.currentTimeMillis,
-                        pollAckTime = System.currentTimeMillis
-                      )
-                      eventBus.postSync(FlinkJobStatusChangeEvent(id, lostState))
                   }
-                })
+              }
             case _ =>
           })
           future
@@ -219,19 +219,23 @@ class FlinkJobStatusWatcher(conf: JobStatusWatcherConfig = JobStatusWatcherConfi
       watchController.jobStatuses.put(trackId, jobState)
       // set jobId to trackIds
       watchController.trackIds.update(trackId)
+
       eventBus.postSync(FlinkJobStatusChangeEvent(trackId, jobState))
     }
 
-    lazy val deployExists = KubernetesRetriever.isDeploymentExists(
-      trackId.namespace,
-      trackId.clusterId
-    )
-
-    if (FlinkJobState.isEndState(jobState.jobState) && !deployExists) {
-      // remove trackId from cache of job that needs to be untracked
-      watchController.unWatching(trackId)
-      if (trackId.executeMode == APPLICATION) {
-        watchController.endpoints.invalidate(trackId.toClusterKey)
+    if (FlinkJobState.isEndState(jobState.jobState)) {
+      trackId.executeMode match {
+        case APPLICATION =>
+          val deployExists = KubernetesRetriever.isDeploymentExists(
+            trackId.namespace,
+            trackId.clusterId
+          )
+          if (!deployExists) {
+            watchController.endpoints.invalidate(trackId.toClusterKey)
+            watchController.unWatching(trackId)
+          }
+        case SESSION =>
+          watchController.unWatching(trackId)
       }
     }
   }
@@ -307,6 +311,7 @@ class FlinkJobStatusWatcher(conf: JobStatusWatcherConfig = JobStatusWatcherConfi
     val jobState = trackId match {
       case id if watchController.canceling.has(id) =>
         logger.info(s"trackId ${trackId.toString} is canceling")
+        watchController.trackIds.invalidate(id)
         FlinkJobState.CANCELED
       case _ =>
         // whether deployment exists on kubernetes cluster
@@ -337,7 +342,7 @@ class FlinkJobStatusWatcher(conf: JobStatusWatcherConfig = JobStatusWatcherConfi
           }
         } else if (isConnection) {
           logger.info("The deployment is deleted and enters the task failure process.")
-          FlinkJobState.of(FlinkHistoryArchives.getJobStateFromArchiveFile(trackId.jobId))
+          FlinkJobState.of(FlinkHistoryArchives.getJobStateFromArchiveFile(trackId))
         } else {
           inferFromPreCache(latest)
         }
@@ -386,7 +391,9 @@ object FlinkJobStatusWatcher {
     current match {
       case FlinkJobState.POS_TERMINATED | FlinkJobState.TERMINATED =>
         previous match {
-          case FlinkJobState.CANCELLING => FlinkJobState.CANCELED
+          case FlinkJobState.CANCELLING => {
+            FlinkJobState.CANCELED
+          }
           case FlinkJobState.FAILING => FlinkJobState.FAILED
           case _ =>
             current match {
@@ -489,52 +496,58 @@ private[kubernetes] object JobDetails {
 
 }
 
-private[kubernetes] object FlinkHistoryArchives {
+private[kubernetes] object FlinkHistoryArchives extends Logger {
 
   @transient
   implicit lazy val formats: DefaultFormats.type = org.json4s.DefaultFormats
 
   private[this] val FAILED_STATE = "FAILED"
 
-  def getJobStateFromArchiveFile(jobId: String): String = Try {
-    require(jobId != null, "[StreamPark] getJobStateFromArchiveFile: JobId cannot be null.")
-    val archivePath = new Path(Workspace.ARCHIVES_FILE_PATH, jobId)
-    FsJobArchivist.getArchivedJsons(archivePath) match {
-      case r if r.isEmpty => FAILED_STATE
-      case r =>
-        r.foreach {
-          a =>
-            if (a.getPath == s"/jobs/$jobId/exceptions") {
-              Try(parse(a.getJson)) match {
-                case Success(ok) =>
-                  val log = (ok \ "root-exception").extractOpt[String].orNull
-                  if (log != null) {
-                    val path = KubernetesDeploymentHelper.getJobErrorLog(jobId)
-                    val file = new File(path)
-                    Files.asCharSink(file, Charsets.UTF_8).write(log)
-                  }
-                case _ =>
+  def getJobStateFromArchiveFile(trackId: TrackId): String = Try {
+    require(trackId.jobId != null, "[StreamPark] getJobStateFromArchiveFile: JobId cannot be null.")
+    val archiveDir = trackId.properties.getProperty(JobManagerOptions.ARCHIVE_DIR.key)
+    if (archiveDir == null) {
+      FAILED_STATE
+    } else {
+      val archivePath = new Path(archiveDir, trackId.jobId)
+      FsJobArchivist.getArchivedJsons(archivePath) match {
+        case r if r.isEmpty => FAILED_STATE
+        case r =>
+          r.foreach {
+            a =>
+              if (a.getPath == s"/jobs/${trackId.jobId}/exceptions") {
+                Try(parse(a.getJson)) match {
+                  case Success(ok) =>
+                    val log = (ok \ "root-exception").extractOpt[String].orNull
+                    if (log != null) {
+                      val path = KubernetesDeploymentHelper.getJobErrorLog(trackId.jobId)
+                      val file = new File(path)
+                      Files.asCharSink(file, Charsets.UTF_8).write(log)
+                      println(" error path: " + path)
+                    }
+                  case _ =>
+                }
+              } else if (a.getPath == "/jobs/overview") {
+                Try(parse(a.getJson)) match {
+                  case Success(ok) =>
+                    ok \ "jobs" match {
+                      case JNothing | JNull =>
+                      case JArray(arr) =>
+                        arr.foreach(
+                          x => {
+                            val jid = (x \ "jid").extractOpt[String].orNull
+                            if (jid == trackId.jobId) {
+                              return (x \ "state").extractOpt[String].orNull
+                            }
+                          })
+                      case _ =>
+                    }
+                  case Failure(_) =>
+                }
               }
-            } else if (a.getPath == "/jobs/overview") {
-              Try(parse(a.getJson)) match {
-                case Success(ok) =>
-                  ok \ "jobs" match {
-                    case JNothing | JNull =>
-                    case JArray(arr) =>
-                      arr.foreach(
-                        x => {
-                          val jid = (x \ "jid").extractOpt[String].orNull
-                          if (jid == jobId) {
-                            return (x \ "state").extractOpt[String].orNull
-                          }
-                        })
-                    case _ =>
-                  }
-                case Failure(_) =>
-              }
-            }
-        }
-        FAILED_STATE
+          }
+          FAILED_STATE
+      }
     }
   }.getOrElse(FAILED_STATE)
 
