@@ -19,25 +19,24 @@ package org.apache.streampark.flink.packer.maven
 
 import org.eclipse.aether.artifact.{Artifact => AetherArtifact}
 
+import java.util.{Collections, Set => JavaSet}
 import java.util.regex.Pattern
 
 case class Artifact(
     groupId: String,
     artifactId: String,
     version: String,
-    classifier: String = null) {
+    classifier: String = null,
+    extensions: JavaSet[String] = Collections.emptySet()) {
 
-  def eq(artifact: AetherArtifact): Boolean = {
-    artifact.getGroupId match {
-      case g if g == groupId =>
-        artifact.getArtifactId match {
-          case "*" => true
-          case a => a == artifactId
-        }
-      case _ => false
+  def filter(artifact: AetherArtifact): Boolean = {
+    (artifact.getGroupId, artifact.getArtifactId) match {
+      case ("*", "*") => true
+      case (g, "*") => g == this.groupId
+      case ("*", a) => a == this.artifactId
+      case (g, a) => g == this.groupId && a == this.artifactId
     }
   }
-
 }
 
 object Artifact {
