@@ -18,26 +18,29 @@
 package org.apache.streampark.flink.packer.maven
 
 import org.apache.streampark.common.conf.{InternalConfigHolder, Workspace}
-import org.apache.streampark.common.conf.CommonConfig.{MAVEN_AUTH_PASSWORD, MAVEN_AUTH_USER, MAVEN_REMOTE_URL}
+import org.apache.streampark.common.conf.CommonConfig.{MAVEN_AUTH_PASSWORD, MAVEN_AUTH_USER, MAVEN_REMOTE_URL, MAVEN_SETTINGS_PATH}
 import org.apache.streampark.common.util.{Logger, Utils}
 
 import com.google.common.collect.Lists
+import org.apache.commons.lang3.StringUtils
 import org.apache.maven.plugins.shade.{DefaultShader, ShadeRequest}
 import org.apache.maven.plugins.shade.filter.Filter
 import org.apache.maven.plugins.shade.resource.{ManifestResourceTransformer, ResourceTransformer, ServicesResourceTransformer}
 import org.apache.maven.repository.internal.MavenRepositorySystemUtils
+import org.apache.maven.settings.Settings
+import org.apache.maven.settings.building.{DefaultSettingsBuilderFactory, DefaultSettingsBuildingRequest}
 import org.codehaus.plexus.logging.{Logger => PlexusLog}
 import org.codehaus.plexus.logging.console.ConsoleLogger
 import org.eclipse.aether.{RepositorySystem, RepositorySystemSession}
 import org.eclipse.aether.artifact.DefaultArtifact
 import org.eclipse.aether.connector.basic.BasicRepositoryConnectorFactory
-import org.eclipse.aether.repository.{LocalRepository, RemoteRepository}
+import org.eclipse.aether.repository.{LocalRepository, Proxy, RemoteRepository}
 import org.eclipse.aether.resolution.{ArtifactDescriptorRequest, ArtifactRequest}
 import org.eclipse.aether.spi.connector.RepositoryConnectorFactory
 import org.eclipse.aether.spi.connector.transport.TransporterFactory
 import org.eclipse.aether.transport.file.FileTransporterFactory
 import org.eclipse.aether.transport.http.HttpTransporterFactory
-import org.eclipse.aether.util.repository.AuthenticationBuilder
+import org.eclipse.aether.util.repository.{AuthenticationBuilder, DefaultMirrorSelector, DefaultProxySelector}
 
 import javax.annotation.{Nonnull, Nullable}
 
@@ -45,17 +48,26 @@ import java.io.File
 import java.util
 
 import scala.collection.JavaConversions._
+import scala.collection.JavaConverters._
 import scala.collection.mutable.ArrayBuffer
-import scala.util.Try
+import scala.util.{Failure, Success, Try}
 
 object MavenTool extends Logger {
 
   private[this] lazy val plexusLog = new ConsoleLogger(PlexusLog.LEVEL_INFO, "streampark-maven")
 
-  private[this] val excludeArtifact = List(
+  /** create maven repository endpoint */
+  private[this] lazy val locator = MavenRepositorySystemUtils.newServiceLocator
+
+  /** default maven local repository */
+  private[this] lazy val localRepo = new LocalRepository(Workspace.MAVEN_LOCAL_PATH)
+
+  private[this] val excludeArtifact = Set(
     Artifact.of("org.apache.flink:force-shading:*"),
+    Artifact.of("org.apache.flink:flink-shaded-force-shading:*"),
     Artifact.of("com.google.code.findbugs:jsr305:*"),
-    Artifact.of("org.apache.logging.log4j:*:*"))
+    Artifact.of("org.apache.logging.log4j:*:*")
+  )
 
   private[this] def getRemoteRepos(): List[RemoteRepository] = {
     val builder =
@@ -76,9 +88,6 @@ object MavenTool extends Logger {
     List(remoteRepository)
   }
 
-  private val isJarFile = (file: File) =>
-    file.isFile && Try(Utils.checkJarFile(file.toURI.toURL)).isSuccess
-
   /**
    * Build a fat-jar with custom jar libraries.
    *
@@ -102,16 +111,34 @@ object MavenTool extends Logger {
     uberJar.delete()
     // resolve all jarLibs
     val jarSet = new util.HashSet[File]
-    jarLibs
-      .map(lib => new File(lib))
-      .filter(_.exists)
-      .foreach {
-        case libFile if isJarFile(libFile) => jarSet.add(libFile)
-        case libFile if libFile.isDirectory =>
-          libFile.listFiles.filter(isJarFile).foreach(jarSet.add)
-        case _ =>
-      }
-    logInfo(s"start shaded fat-jar: ${jarLibs.mkString(",")}")
+    jarLibs.foreach {
+      jar =>
+        new File(jar) match {
+          case jarFile if jarFile.exists() =>
+            if (jarFile.isFile) {
+              Try(Utils.checkJarFile(jarFile.toURI.toURL)) match {
+                case Success(_) => jarSet.add(jarFile)
+                case Failure(e) => logWarn(s"buildFatJar: error, ${e.getMessage}")
+              }
+            } else {
+              jarFile.listFiles.foreach(
+                jar => {
+                  if (jar.isFile) {
+                    Try(Utils.checkJarFile(jar.toURI.toURL)) match {
+                      case Success(_) => jarSet.add(jar)
+                      case Failure(e) =>
+                        logWarn(
+                          s"buildFatJar: directory [${jarFile.getAbsolutePath}], error: ${e.getMessage}")
+                    }
+                  }
+                })
+            }
+          case _ =>
+        }
+    }
+
+    logInfo(s"start shaded fat-jar: ${jarSet.mkString(",")}")
+
     // shade jars
     val shadeRequest = {
       val req = new ShadeRequest
@@ -128,7 +155,7 @@ object MavenTool extends Logger {
       }
       req.setResourceTransformers(transformer.toList)
       // issue: https://github.com/apache/incubator-streampark/issues/2350
-      req.setFilters(List(new ShadeFilter))
+      req.setFilters(List(new ShadedFilter))
       req.setRelocators(Lists.newArrayList())
       req
     }
@@ -142,7 +169,7 @@ object MavenTool extends Logger {
   /**
    * Build a fat-jar with custom jar librarties and maven artifacts.
    *
-   * @param dependencyInfo
+   * @param artifact
    *   maven artifacts and jar libraries for building a fat-jar
    * @param outFatJarPath
    *   output paths of fat-jar, like "/streampark/workspace/233/my-fat.jar"
@@ -150,10 +177,10 @@ object MavenTool extends Logger {
   @throws[Exception]
   def buildFatJar(
       @Nullable mainClass: String,
-      @Nonnull dependencyInfo: DependencyInfo,
+      @Nonnull artifact: MavenArtifact,
       @Nonnull outFatJarPath: String): File = {
-    val jarLibs = dependencyInfo.extJarLibs
-    val arts = dependencyInfo.mavenArts
+    val jarLibs = artifact.extJarLibs
+    val arts = artifact.mavenArts
     if (jarLibs.isEmpty && arts.isEmpty) {
       throw new Exception(s"[StreamPark] streampark-packer: empty artifacts.")
     }
@@ -161,6 +188,9 @@ object MavenTool extends Logger {
     buildFatJar(mainClass, jarLibs ++ artFilePaths, outFatJarPath)
   }
 
+  def resolveArtifactsAsJava(mavenArtifacts: util.Set[Artifact]): util.Set[File] = resolveArtifacts(
+    mavenArtifacts.toSet).asJava
+
   /**
    * Resolve the collectoin of artifacts, Artifacts will be download to ConfigConst.MAVEN_LOCAL_DIR
    * if necessary. notes: Only compile scope dependencies will be resolved.
@@ -172,48 +202,68 @@ object MavenTool extends Logger {
    */
   @throws[Exception]
   def resolveArtifacts(mavenArtifacts: Set[Artifact]): Set[File] = {
-    if (mavenArtifacts == null) Set.empty[File];
-    else {
-      val (repoSystem, session) = getMavenEndpoint()
-      val artifacts = mavenArtifacts.map(
-        e => {
-          new DefaultArtifact(e.groupId, e.artifactId, e.classifier, "jar", e.version)
-        })
-      logInfo(s"start resolving dependencies: ${artifacts.mkString}")
-
-      val remoteRepos = getRemoteRepos()
-      // read relevant artifact descriptor info
-      // plz don't simplify the following lambda syntax to maintain the readability of the code.
-      val resolvedArtifacts = artifacts
-        .map(artifact => new ArtifactDescriptorRequest(artifact, remoteRepos, null))
-        .map(artDescReq => repoSystem.readArtifactDescriptor(session, artDescReq))
-        .flatMap(_.getDependencies)
-        .filter(_.getScope == "compile")
-        .filter(x => !excludeArtifact.exists(_.eq(x.getArtifact)))
-        .map(_.getArtifact)
-
-      val mergedArtifacts = artifacts ++ resolvedArtifacts
-      logInfo(s"resolved dependencies: ${mergedArtifacts.mkString}")
-
-      // download artifacts
-      val artReqs =
-        mergedArtifacts.map(artifact => new ArtifactRequest(artifact, remoteRepos, null))
-      repoSystem
-        .resolveArtifacts(session, artReqs)
-        .map(_.getArtifact.getFile)
-        .toSet
+    if (mavenArtifacts == null) {
+      return Set.empty[File]
     }
+
+    val (repoSystem, session) = getRepositoryEndpoint()
+
+    val exclusions = mavenArtifacts
+      .flatMap(_.extensions.map(_.split(":")))
+      .map(a => Artifact(a.head, a.last, null)) ++ excludeArtifact
+
+    val remoteRepos = getRemoteRepos()
+
+    val exclusionAll = exclusions.exists(e => e.groupId == "*" && e.artifactId == "*")
+
+    val artifacts = mavenArtifacts.map(
+      e => new DefaultArtifact(e.groupId, e.artifactId, e.classifier, "jar", e.version))
+
+    // read relevant artifact descriptor info and excluding items if necessary.
+    val dependencies =
+      if (exclusionAll) Set.empty[DefaultArtifact]
+      else {
+        artifacts
+          .map(artifact => new ArtifactDescriptorRequest(artifact, remoteRepos, null))
+          .map(descReq => repoSystem.readArtifactDescriptor(session, descReq))
+          .flatMap(_.getDependencies)
+          .filter(_.getScope == "compile")
+          .filter(dep => !exclusions.exists(_.filter(dep.getArtifact)))
+          .map(_.getArtifact)
+      }
+
+    val mergedArtifacts = artifacts ++ dependencies
+
+    logInfo(
+      s"""
+         |start resolving dependencies...
+         |--------------------------------------------------------------------------------
+         ||User-declared dependencies list：
+         |${artifacts.mkString(",\n")}
+         |
+         ||Indirect dependencies list:
+         |${dependencies.mkString(",\n")}
+         |
+         ||Exclusion indirect dependencies list:
+         |${exclusions.map(x => s"${x.groupId}:${x.artifactId}").mkString(",\n")}
+         |
+         ||Final dependencies list:
+         |${mergedArtifacts.mkString(",\n")}
+         |--------------------------------------------------------------------------------
+         |""".stripMargin
+    )
+
+    // download artifacts
+    val artReq = mergedArtifacts.map(a => new ArtifactRequest(a, remoteRepos, null))
+
+    repoSystem
+      .resolveArtifacts(session, artReq)
+      .map(_.getArtifact.getFile)
+      .toSet
   }
 
   /** create composite maven endpoint */
-  private[this] def getMavenEndpoint(): (RepositorySystem, RepositorySystemSession) = {
-
-    /** create maven repository endpoint */
-
-    lazy val locator = MavenRepositorySystemUtils.newServiceLocator
-
-    /** default maven local repository */
-    lazy val localRepo = new LocalRepository(Workspace.MAVEN_LOCAL_PATH)
+  private[this] def getRepositoryEndpoint(): (RepositorySystem, RepositorySystemSession) = {
 
     def newRepoSystem(): RepositorySystem = {
       locator.addService(
@@ -228,6 +278,40 @@ object MavenTool extends Logger {
     def newSession(system: RepositorySystem): RepositorySystemSession = {
       val session = MavenRepositorySystemUtils.newSession
       session.setLocalRepositoryManager(system.newLocalRepositoryManager(session, localRepo))
+
+      val setting = getSettings()
+      if (setting != null) {
+        // 1) mirror
+        val mirrors = setting.getMirrors
+        if (mirrors.nonEmpty) {
+          val defaultMirror = new DefaultMirrorSelector()
+          setting.getMirrors.foreach {
+            mirror =>
+              defaultMirror.add(
+                mirror.getId,
+                mirror.getUrl,
+                "default",
+                false,
+                mirror.getMirrorOf,
+                null)
+          }
+          session.setMirrorSelector(defaultMirror)
+        }
+
+        // 2) proxy
+        val proxies = setting.getProxies
+        if (proxies.nonEmpty && proxies.exists(_.isActive)) {
+          val proxySelector = new DefaultProxySelector()
+          proxies.foreach(
+            p => {
+              if (p.isActive) {
+                val proxy = new Proxy(p.getProtocol, p.getHost, p.getPort)
+                proxySelector.add(proxy, p.getNonProxyHosts)
+              }
+            })
+          session.setProxySelector(proxySelector)
+        }
+      }
       session
     }
 
@@ -236,13 +320,29 @@ object MavenTool extends Logger {
     (repoSystem, session)
   }
 
-  class ShadeFilter extends Filter {
+  private def getSettings(): Settings = {
+    val settingPath = InternalConfigHolder.get[String](MAVEN_SETTINGS_PATH)
+    if (StringUtils.isNotBlank(settingPath)) {
+      val settingFile = new File(settingPath)
+      if (settingFile.exists() && settingFile.isFile) {
+        val settingsBuilderFactory = new DefaultSettingsBuilderFactory()
+        val settingsBuilder = settingsBuilderFactory.newInstance
+        val settingRequest = new DefaultSettingsBuildingRequest()
+        settingRequest.setGlobalSettingsFile(settingFile)
+        settingRequest.setUserSettingsFile(settingFile)
+        return settingsBuilder.build(settingRequest).getEffectiveSettings
+      }
+    }
+    null
+  }
+
+  private class ShadedFilter extends Filter {
     override def canFilter(jar: File): Boolean = true
 
     override def isFiltered(name: String): Boolean = {
       if (name.startsWith("META-INF/")) {
         if (name.endsWith(".SF") || name.endsWith(".DSA") || name.endsWith(".RSA")) {
-          logInfo(s"shade ignore file: $name")
+          logInfo(s"shaded ignore file: $name")
           return true
         }
       }
@@ -251,5 +351,4 @@ object MavenTool extends Logger {
 
     override def finished(): Unit = {}
   }
-
 }
