@@ -16,7 +16,7 @@
  */
 package org.apache.streampark.flink.core
 
-import org.apache.streampark.common.conf.ConfigConst._
+import org.apache.streampark.common.conf.ConfigConst.printLogo
 import org.apache.streampark.flink.core.EnhancerImplicit._
 
 import org.apache.flink.api.common.JobExecutionResult
@@ -34,13 +34,13 @@ import java.util.Optional
 abstract class FlinkTableTrait(val parameter: ParameterTool, private val tableEnv: TableEnvironment)
   extends TableEnvironment {
 
-  def start(): JobExecutionResult = {
+  def start(): Unit = {
     val appName = parameter.getAppName(required = true)
     execute(appName)
   }
 
-  def execute(jobName: String): JobExecutionResult = {
-    printLogo(s"FlinkTable $jobName Starting...")
+  @deprecated override def execute(jobName: String): JobExecutionResult = {
+    printLogo(s"Flink Table batch job: $jobName Starting...")
     null
   }
 
