@@ -18,7 +18,6 @@ package org.apache.streampark.flink.core
 
 import org.apache.flink.kubernetes.kubeclient.FlinkKubeClient
 import org.apache.flink.kubernetes.kubeclient.resources.KubernetesService
-import org.apache.flink.kubernetes.kubeclient.resources.KubernetesService.ServiceType
 
 import java.util.Optional
 
@@ -26,7 +25,7 @@ class FlinkKubernetesClient(kubeClient: FlinkKubeClient)
   extends FlinkKubernetesClientTrait(kubeClient) {
 
   override def getService(serviceName: String): Optional[KubernetesService] = {
-    kubeClient.getService(ServiceType.REST_SERVICE, serviceName)
+    kubeClient.getService(serviceName)
   }
 
 }
